@@ -1,5 +1,6 @@
+# frozen_string_literal: true
+
 require "jekyll"
-require "coffee-script"
 require "jekyll-coffeescript/version"
 require "jekyll/converters/coffeescript"
 
